===============================
pykraken
===============================

.. image:: https://img.shields.io/pypi/v/pykraken.svg
        :target: https://pypi.python.org/pypi/pykraken

.. image:: https://img.shields.io/travis/euri10/pykraken.svg
        :target: https://travis-ci.org/euri10/pykraken

.. image:: https://readthedocs.org/projects/pykraken/badge/?version=latest
        :target: https://readthedocs.org/projects/pykraken/?badge=latest
        :alt: Documentation Status


python implementation of https://www.kraken.com/ API

* Free software: ISC license
* Documentation: https://pykraken.readthedocs.org.

Features
--------

python implementation of https://www.kraken.com/ API

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
